from nonebot import on_command
from nonebot.rule import to_me
from nonebot.matcher import Matcher
from nonebot.adapters.onebot.v11 import Bot, Event, Message
from nonebot.params import Arg, CommandArg, ArgPlainText
from .message import message_sign

import random
import time

command = on_command('/抽签', priority=6)
@command.handle()
async def lq_():
    await command.send(
        message="确定要抽取吗"
    )

@command.got("pb")
async def pq_(reply: str = ArgPlainText('pb')):
    if reply == '确定' or 'yes' or '抽取' or '嗯':
        for i in range(3):
            a = random.randint(0,100)
            if a >= 5 :
                pd=True
                await command.send(
                    message="抽到了正签"
                )
                break
            else:#为了模拟真实抛杯才设置空签
                await command.send(
                    message="是空签呢",
                    at_sender=True,
                )
                pd=False
                break

        if pd is True:
            await command.finish(message=f"\n{random.choice(message_sign)}",at_sender=True)
        else:
           await command.finish()
    else:
        await command.finish('\n放弃了抽取',at_sender=True,)





#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages  # 这个包没有的可以pip一下

setup(
    name="nonebot_plugin_CyberSensoji",
    version="0.0.2",
    keywords=["pip", "CyberSensoji"],			# 关键字
    description="A plugin for nonebot", 	# 描述
    long_description="A plugin for nonebot",
    license="MIT Licence",		# 许可证

    # 项目相关文件地址，一般是github项目地址即可
    url="https://github.com/Raidenneox/nonebot_plugin_CyberSensoji",
    author="Raidenneox",			# 作者
    author_email="longahead@outlook.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=["nonebot2", "nonebot-adapter-onebot"]  # 这个项目依赖的第三方库
)



message_sign=[
            "大吉\n七宝浮图塔\n高峰顶上安\n众人皆仰望\n莫作等闲看\n七宝浮图塔\n就像出现了用美丽宝石做成的佛塔般地，似乎会有非常好的事情。\n高峰顶上安\n因为能改用放眼万事的立场，可以得到周围的人们的信赖吧。\n众人皆仰望\n合乎正道的你的行为，能被很多人的认同及鼓励。\n莫作等閒看\n不用随便的态度看事情，用正确的心思会招来更多的好的结果。愿望：会充分地实现吧。\n疾病：会治癒吧。\n盼望的人：会出现吧。\n遗失物：变得迟迟地才找到吧。\n盖新居、搬家、嫁娶、旅行、交往等：全部很好吧。万事行为谨慎。粗心大意行事的话，就会发生意想之外的灾害吧。",
            "小吉\n月被浮云翳\n立事自昏迷\n幸乞阴公祐\n何虑不开眉\n月被浮云翳\n似乎抱着强烈的愿望，但是照目前的样子，似乎无法达成愿望。\n立事自昏迷\n因为光是想着要怎么作，持续着没有决心的情形。\n幸乞隂公祐\n为了人而变得尽全力努力，幸福将会来到。\n何虑不开眉\n似乎会有令人高兴的事情发生。根据这件好事，不担心未来的事也没有关係了。\n愿望：因为持续不断地努力，必定会实现。\n疾病：虽然拖长，但是之后可以康复吧。\n盼望的人：迟迟地才出现吧。\n遗失物：不能找出来吧。\n交往：要节制吧。\n盖新居、搬家：都不坏吧。\n结亲缘、旅行：顺利进行吧。",
            "凶\n愁恼损忠良\n青霄一炷香\n虽然防小过\n闲虑觉时长愁恼损忠良\n层层迭迭叹气与苦恼，被回报的事很少吧。\n青霄一炷香\n就像向着天烧香祈祷般地，你的愿望无法传达天听吧。\n虽然防小过\n虽这样说，但就算只有一点点善行也好，作了可以逃离灾厄吧。\n闲虑觉时长\n东想西想之间，似乎不知不觉就像过了很长的时间。等待时机的到来吧。\n愿望：难实现吧。\n疾病：虽然拖长，但是会治好吧。\n遗失物：难以找到吧。\n盼望的人：要花很久的时间吧。\n旅行：因为很坏，放弃吧。\n盖新居搬家：勉勉强强地算好吧。\n结婚交往：要节制吧。",
            "吉\n累有兴云志\n君恩禄未封\n若逢侯手印\n好事始总总\n累有兴云志\n拼命地要出人头地，可以看出你的志向。\n君恩禄未封\n但是遗憾地是，你的不成熟还不能得到居上位者的认同。\n若逢侯手印\n然而，就像是如果已经写了好文章的话，就立刻得到认同般地，好好传递自己的心思是很重要的。\n好事始总总\n好事也似乎会越来越接踵而起吧\n愿望：能实现吧。如果这样的话，终生幸福吧。\n疾病：变得迟迟地才会治好吧。\n遗失物：迟迟地才找到吧。\n盼望的人：会出现吧。\n旅行：途中要忍耐各式各样的困难吧。\n盖新居、搬家、结亲缘、交往：万事都好吧。",
            "凶\n家道未能昌\n危危保祸殃\n暗云侵月桂\n佳人一炷香\n家道未能昌\n就算试着努力家业，和努力相比却难以繁盛起来吧。\n危危保祸殃\n不是一生灾祸，只是危险的事比较多而已吧。\n暗云侵月桂\n像乌云遮月一样，一生阻碍比较多吧。\n佳人一炷香\n在身份高贵的妇人房裡，各种想法像香一样扩散开来般，心裡无法平静吧。\n愿望：难以实现吧。\n疾病：难治好吧。\n遗失物：难找到吧。\n盼望的人：不会出现吧。\n盖新居、搬家：先放弃，暂时观察情况再说吧。\n结亲缘、旅行、交往：因为万事凶恶，请诸行为慎重行事。",
            "末吉\n宅墓鬼凶多\n人事有爻讹\n伤财防损失\n祈福始中和\n宅墓鬼凶多\n家中恐怕有灾祸。\n行为慎重，抱着深深的信心，这样可以带来好的结果。\n人事有爻讹\n个人的问题或遭遇，过错或过失很多，事情难以进展吧。\n伤财防损失\n就算破财，也会有所得。\n祈福始中和\n因为竭尽祈求神佛的力量，自己尽力努力，能到幸福吧。\n愿望：难以实现吧。\n疾病：康复很花时间吧。\n遗失物：难找到吧。\n盼望的人：迟迟地才出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结亲缘、交往：坏吧。",
            "凶\n登舟待便风\n月色暗朦胧\n欲辗香轮去\n高山千万重\n登舟待便风\n像风不吹船无法前进一样，就算採取行动也难以向前发展吧。\n月色暗朦胧\n就像月亮被乌云笼罩着，前后都无法看见一样，对事情，似乎作一些莽撞的行为。\n欲辗香轮去\n为了逃离灾难，想请託别人教导怎么作，但是况状似乎变得很困难。\n高山千万重\n就像在登险峻的重重山峦车子难行般地，就算思考各种手段，事情的解决还是困难吧。但是现在还是静静的过生活吧。\n愿望：难以实现吧。\n疾病：难以治癒吧。\n遗失物：难以找到吧。\n盼望的人：不会出现吧。\n盖新居、搬家：换时间吧。\n结亲缘、喜庆祝贺、旅行、交往：不好吧。",
            "大吉\n勿头中见尾\n文华须得理\n禾刀自偶然\n当遇非常喜\n勿头中见尾\n在脑海裡没有对失败或结果的恐惧，抬头挺胸地朝着目标达成而努力吧。\n文华须得理\n无论是文学或武术都能得到真理，要有充实自己的心态吧。\n禾刀自偶然\n就像用刀来割稻般地，会得到成果，幸福会自然地到来吧。\n当遇非常喜\n如果正心地守道的话，可以变得幸福吧\n愿望:会实现吧。\n疾病:会治好。请注意养生吧。\n遗失物:可以找到吧。\n盼望的人 ：会出现吧。\n盖新居、搬家、交往 ：是好事吧。\n旅行：途中请不要粗心大意吧。\n结亲缘：全都是好的吧。",
            "大吉\n有名须得遇\n三望一朝迁\n贵人来指処\n华果応时鲜\n有名须得遇\n按照所想的，梦想实现，名声也广传人间吧。\n三望一朝迁\n就像三个愿望可以完全的实现般地，全部能一次完全的被实现吧。\n贵人来指处\n从比自己身份地位高的人，给予各式各样令人欣喜的事吧。\n华菓应时鲜\n像是随着四季循环花会开、会结果一样，每天努力会有成果，好运会展开吧。\n愿望:会实现吧。\n疾病:会治好吧。\n遗失物:会找到吧。\n盼望的人:会出现吧。\n盖新居、搬家:好吧。\n结亲缘、交往:全都好吧。\n旅行:没问题吧。",
            "大吉\n旧用多成破\n新更始见财\n改求云外望\n枯木遇春开\n旧用多成破\n过去的不幸或许多烦恼也会消去，好事将发生吧。\n新更始见财\n随着新的愿望的出现，财富也会增加。\n改求云外望\n就像是在云上追求愿望般地，请试着追求高高的愿望。\n枯木遇春开\n像枯木在春天开花一样，一定会变得很繁盛吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：立刻会找到吧。\n盼望的人：会出现吧。\n盖新居、搬家：会变为好结果吧。\n结亲缘、旅行、交往：全部变为好结果吧。",
            "大吉\n有禄兴家业\n文华达帝都\n云中乘好箭\n兼得贵人扶\n有禄兴家业\n幸福与收入具足，家业也渐渐繁盛起来吧。\n文华达帝都\n才能显现出来，可得世人的好评价吧。\n云中乘好箭\n就算是向空中放箭也可以得到好的猎物般地，任何事也都可以成功吧。\n兼得贵人扶\n得到这样的幸福之外，加上还可以得到居上位者或神佛的帮助吧。\n愿望：会充分地实现吧。\n疾病：会治好吧。\n遗失物：会找到吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：没问题吧。\n结婚、交往：全部都能得到好结果吧。",
            "大吉\n杨柳遇春时\n残花发旧枝\n重重霜雪裡\n黄金色更辉\n杨柳遇春时\n像柳树也逢春增添绿色般地，希望也会出现吧。\n残花发旧枝\n像老枝也发芽，开花般地，喜事会到来吧。\n重重霜雪裡\n像在重重霜或雪中般地，无论怎样过去的劳苦不断吧，\n黄金色更辉\n但是像黄金色无论到何时，都闪亮耀眼般地，不要忘以前的劳苦，用诚实的心过生活吧。\n愿望：会实现吧。\n疾病：会变好吧。\n遗失物：会回来吧。\n盼望的人：晚出现吧。\n盖新居、搬家：会成为好结果吧。\n旅行：没有阻碍吧。\n结婚、交往：全都适当吧。",
            "大吉\n手把大阳辉\n东君发旧枝\n稼苗方欲秀\n犹更上云梯\n手把大阳辉\n如果时机来到的话，抱着勇气努力做事，可以过着充实的生活吧。\n东君发旧枝\n就像是老枝条，随着春天到来，花就开了一样，运势会开展吧。\n稼苗方欲秀\n就像稻苗也是如果春天来了的话，就会生长般地，你也会繁荣昌盛吧。\n犹更上云梯\n像是也能爬上难登的云梯般，因为更加地持续努力就会成功吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：立刻找就能找到吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：在春天和夏天好吧。\n结婚、交往：全部都好吧。",
            "末吉\n玉石未分时\n忧心转更悲\n前途通大道\n花发应残枝\n玉石未分时\n就像是就算有宝玉，哪一个是宝石哪一个是石头还分不清楚般地，没办法分辨事物的状况。\n忧心转更悲\n就算是想要出人头地，但会为了各式各样的事情而心痛、叹息、悲伤也说不定。\n前途通大道\n如果忍耐劳苦，将来自然地看得到未来的去向吧。\n花发应残枝\n然后像枯枝开花般地，愿望会实现吧。\n愿望：很花时间但会实现吧。\n疾病：会拖长吧，但是不会影响性命吧。\n遗失物：难出现吧。\n盼望的人：似乎会变得迟吧。\n盖新居、搬家：不太好吧。\n结婚：现在要节制，如果往后的话好吧。\n旅行、交往：避开吧。",
            "凶\n年乖数亦孤\n久病未能苏\n岸危舟未发\n龙卧失明珠\n年乖数亦孤\n朋友年年地减少，变成孤单一人，生活变得不自由吧。\n久病未能苏\n长期的疾病虽然种种地想治癒，但是却康复无望吧。\n岸危舟未发\n就像船想靠岸，因为危险不能靠岸般地，想做点什么，但是因为有阻碍，总是不能着手进行吧。\n龙卧失明珠\n像是龙失去重要的龙珠般地，人也失去希望吧。\n愿望：难以实现吧。\n疾病：危险吧。\n遗失物：难找回吧。\n盼望的人：不会出现吧。\n盖新居、搬家：都不好吧。\n旅行、结亲缘：坏吧。",
            "凶\n破改重成望\n前途喜亦宁\n贵人相助处\n禄马照前程\n破改重成望\n抛开至今为止的愿望，期待别的愿望为佳吧。\n前途喜亦宁\n要前往的目的地有令人欣喜的事，变为安稳的心情吧。\n贵人相助处\n因为得到居上位者（观世音菩萨）的帮助，越来越得到力量吧。\n禄马照前程\n像是用马载着上天给予的宝物，前方光明照耀般地，在人世间地位或收入等也和想的一样地充满吧。\n愿望：能被实现吧。\n疾病：会康复吧。\n遗失物：会出现吧。\n盼望的人：会来吧。\n盖新居、搬家：会有好结果吧。\n旅行：好吧。结亲缘、交往：全部会变成好结果吧。",
            "凶\n怪异防忧恼\n人宅见分离\n惜华还值雨\n杯酒惹闲非\n怪异防忧恼\n如果作一些想要防止降落在自己身上的危险的事的话，反而烦恼似乎变多了。\n人宅见分离\n不知不觉间，不好的事情持续着，似乎会有家人分离的事。\n惜华还值雨\n就像捨不得花凋谢的话，更是会被雨淋凋萎般地，不好的是似乎持续着。\n杯酒惹闲非\n因为无法按照所想的发展，沉溺于喝酒之类的，似乎还是会产生坏想法吧。\n愿望：难实现吧。\n疾病：康复需要长时间吧。\n遗失物：不会出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：先放弃，暂时观察情况再说吧。\n旅行：似乎引起坏的结果吧。\n婚事、交往：全部不好吧。",
            "吉\n离暗出明时\n麻衣变绿衣\n旧忧终是退\n遇禄应交辉\n离暗出明时\n就像乌云的天空也渐渐地晴朗，可以看到月亮般地，今后渐渐地希望能被实现吧。\n麻衣变绿衣\n就像脱掉破旧的衣服，穿着漂亮的衣服般地，用全新的心情做好每天的善行吧。\n旧忧终是退\n长时间的悲伤也渐渐地消散吧。\n遇禄应交辉\n福德自然地增加，人生光辉闪耀吧。\n愿望：会实践吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结亲缘、交往：全部变为好结果吧。",
            "小吉\n家道生荆棘\n儿孙防虎威\n香前祈福厚\n方得免分离\n家道生荆棘\n家裡的生意有阻碍，事情不按照所想地进行吧。\n儿孙防虎威\n子或孙如果常听长辈（居上位者）的话，就会没事吧。\n香前祈福厚\n抱持着强烈的信心，如果竭尽真诚的心的话，将来会有好事吧。\n方得免分离\n得到福德，本来别离的命运的人（物）会在不用分别的情况下解决吧。\n愿望：能实现一半吧。\n疾病：虽然长期得病，但是不会危及性命吧。\n遗失物：大概找回不来了吧。\n盼望的人：变成迟迟地出现吧。\n盖新居、搬家：不好也不坏吧。\n旅行：节制比较好吧。\n结婚：不会到达好的结果吧。\n交往：节制吧。",
            "吉\n月出渐分明\n家财每每兴\n何言先有滞\n更变立功名\n月出渐分明\n像是月亮也出来了，渐渐地变明朗般地，终于渐渐地希望也能被实现吧。\n家财每每兴\n家中的财产也能慢慢地累积，家中的生意也会繁盛起来吧。\n何言先有滞\n至今为止不能畅快地运作的事情，最后也会向好的方面进行吧。\n更变立功名\n更进一步地，世间的评价好，变得能得到利益吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会来吧。\n盖新居、搬家：好吧。\n结婚、交往：全部都得到好结果吧。\n旅行：好吧。",
            "吉\n洗出经年否\n光华得再清\n所求终吉利\n重日照前程\n洗出经年否\n像是至今为止的坏事已被洗去般地，变成轻鬆畅快的状况吧。\n光华得再清\n好事再度发生，更加地带来比现在更好的结果吧。\n所求终吉利\n愿望都会变成好结果吧。\n重日照前程\n随着日子一天又一天的过，前途增添光辉，状况也变好吧。\n愿望：能被实现吧。\n疾病：虽然会恢复但是切忌粗心大意。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n结婚：会得到好结果吧。\n旅行、交往：全部好吧。",
            "吉\n渐渐浓云散\n看看月再明\n逢春华菓秀\n雨过竹重青\n渐渐浓云散\n像浓云渐渐变无，万里晴空般地，问题也解决，似乎好事会发生。\n看看月再明\n像月亮再出现，于澄净的天空放光明般地，心情也轻鬆吧。\n逢春华菓秀\n就像草木在春天生气勃勃，花也盛开而变得色彩缤纷般地，过着充实的生活，也变得幸福吧。\n雨过竹重青\n像竹子也遇雨增添色彩般，如果人也连连遇好事的话，越来越能得到好结果吧。\n愿望：虽然能被实现，但是变得比较晚吧。\n疾病：因为会治好，耐心等待康复吧。\n遗失物：虽然会出现但很迟吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n结婚、旅行、交往：全都好吧。",
            "吉\n红云随步起\n一箭中青霄\n鹿行千里远\n争知去路遥\n红云随步起\n已经能看到好的徵兆。要前往的将来会遇到好事吧。\n一箭中青霄\n你也像向青空射出的箭般地作吧。这样的话，无论什么愿望也都没问题，会实现吧。\n鹿行千里远\n但是受到眼前的成功的影响骄傲自大的话，就会变得看不到目标吧。通盘的判断然后行动是很重要的吧。\n争知去路遥\n因为过于自信会招致失败，小心期望过高，诚实是很重要的事。\n愿望：虽然会实现，但是要考虑能力吧。\n疾病：难以康复吧。\n遗失物：难以找到吧。\n盼望的人：不能出现吧。\n盖新居、搬家：好吧。\n结婚、交往：好吧。\n旅行：没问题吧。",
            "凶\n三女莫相逢\n盟言说未通\n门裡心肝挂\n缟素子重重\n三女莫相逢\n产生不合道理的慾望等等的事，请不要做身为人不可以犯的错误行为吧。\n盟言说未通\n光只是口头约束，没有实行的话，就会与对方心意无法相通。\n门裡心肝挂\n因此，烦恼、苦闷也是不行的。抱持着信仰心吧。\n缟素子重重\n不这样的话，只会发生不吉利的事吧。因此从各种面向，好好地分辨黑白是非吧。\n愿望：不会实现吧。\n疾病：虽然拖很长，但会治好吧。\n遗失物：变成到后来才找到吧。\n盼望的人：不能出现吧。\n盖新居、搬家：不好吧。\n旅行：不好吧。\n结婚、交往：变成不好的结果吧。",
            "吉\n枯木逢春生\n前途必利亨\n亦得佳人箭\n乘车禄自行\n枯木逢春生\n像草木在春天发芽，绿叶生长茂盛般地，随着时间繁荣昌盛吧。\n前途必利亨\n去路必有好事发生，能幸福吧。\n亦得佳人箭\n能邂逅很棒的人吧。\n乘车禄自行\n变得能得到崇高地位、财产吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：迟迟才来吧。\n盖新居、搬家：似乎没问题。\n结婚、旅行、交往：全部都变成好结果吧。",
            "吉\n将军有异声\n进兵万里程\n争知临敌处\n道胜却虚名\n将军有异声\n平日的指导力得到部下的信赖，大家听你的指挥吧。\n进兵万里程\n就像是无论在多远的人都尊崇将军的命令，大批士兵向前行进般地，即使多么困难的工作都能得到身边的人或部下的帮助吧。\n争知临敌处\n但是，努力急着成功都徒劳无功吧。\n道胜却虚名\n就算是达成了目标，也会变成白费力气吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：会变成好结果吧。",
            "吉\n望禄应重山\n花红喜悦颜\n举头看皎月\n渐出黑云间\n望禄应重山\n像要越过重重相连的山脉般，因为克服辛劳又痛苦的事，没多久就能得到上天给予的幸福吧。\n花红喜悦颜\n像红色美丽的花朵已经绽放般的喜悦充满脸上吧。\n举头看皎月\n就像如果看到月亮的话，云也消散了，清澈地能看到般地，变成是在人生上能够发挥能力的时期吧。\n渐出黑云间\n就像终于从又厚又黑的云中脱离般地，痛苦与烦恼的每天过去了，围绕而来是沉静安心的心情吧。但是，请多加注意，切忌粗心大意。\n愿望：会实现吧。\n疾病：会治好吧，但切忌粗心大意。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：非常好吧。\n结婚、交往：全部都变成好结果吧。",
            "凶\n意速无船渡\n波深必误身\n切须回旧路\n方可免灾迍\n意速无船渡\n像是就算心裡很着急，船却不前进般地，只是焦急，事情没有改变吧。\n波深必误身\n像是就算想勉强渡过海洋或河川，波浪又高又危险般地，就算想快点到达目的地贯彻事情，却反而变成自己绑着自己的脖子的结果吧。\n切须回旧路\n想在异乡出人头地，不如回到故乡静静地生活比较好吧。\n方可免灾迍\n如果这样的话，有灾害也能逃离吧，自己也会变得安泰吧。\n愿望：难以实现吧。\n疾病：如果长期养生的话会治好吧。\n遗失物：难出现吧。\n盼望的人：变得迟迟地才出现吧。\n盖新居、搬家：坏吧。\n结婚、交往：坏吧。",
            "吉\n忧轗渐消融\n求名得再通\n宝财临禄位\n当遇主人公\n忧轗渐消融\n悲伤或担心的事终于消失了吧。\n求名得再通\n如果想声名远播的话，能像以前一样再次向身边的人传播名声吧。\n宝财临禄位\n收入或地位也变成如同希望一样实现吧。\n当遇主人公\n能遇到好的长官，慢慢地向成功迈进吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n结婚、交往：全都好吧。",
            "半吉\n仙鹤立高枝\n防他暗箭亏\n井畔刚刀利\n户内更防危\n仙鹤立高枝\n就算吉利的鹤想停在高高的树枝上，没办法到达般地，虽有强烈的愿望但阻碍很多吧。\n防他暗箭亏\n就像在黑暗的夜晚中，要难防范不知从哪飞来的箭般地，困难是能想像得到的吧。\n井畔刚刀利\n就算鹤站在泉水中，因为有又硬又锐利的刀子，似乎有危险般地，似乎要发生很多妨碍、阻碍的事吧。\n户内更防危\n不单单只是外面的事，家裡的危机也是不担心不行。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：如果能祈求神佛的保佑，会变成勉强可以的结果吧。\n旅行：坏吧。\n结婚、交往：节制吧。",
            "末吉\n鲲鲸未变时\n且守碧潭溪\n风云兴巨浪\n一息过天涯\n鲲鲸未变时\n因为鲲鲸是很大的鱼，不知不觉会变成大鸟。但是，因为现在尚未变化，一直抱着很大的希望，但是还不能实现的状态吧。\n且守碧潭溪\n就像暂时守着深青色的溪流中，等待时机的到来般地，现在天天的行动都要保守，等待幸运的到来吧。\n风云兴巨浪\n这么做的话，时来运转，变成大鸟的时候会到来。掀起浪花，有着向天空飞去的沸腾的心。幸运到来，朝向成功，拼命地不断努力是很重要的。\n一息过天涯\n这样做就会一口气飞向天空吧。步向成功的道路，在世间似乎会好名声远播的事。\n愿望：虽能被实现，但要考虑时机吧。\n疾病：拖很久吧。\n遗失物：变得迟迟地才出现吧。\n盼望的人：变得迟迟地才出现吧。\n盖新居、搬家：没阻碍吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "吉\n似玉藏深石\n休将故眼看\n一朝良匠别\n方见宝光寒\n似玉藏深石\n就像是不知道宝石藏深在石头下般地，就算有才能，不在意，不努力振作施展才能的话，什么都不能得到吧。\n休将故眼看\n用不管眼前事物的方式，才能是会就这样埋没下去吧。\n一朝良匠别\n可是如果不断持续地努力的话，不知不觉能被良师、益友发现。\n方见宝光寒\n然后，就像被磨光的宝石闪闪发光地出现般，能展现成果，能为社会尽心力吧。\n愿望：会实现吧。\n疾病：虽然会拖长，但是不会失去生命。\n遗失物：会出现吧。\n盼望的人：变得迟迟地才出现吧。\n盖新居、搬家：好吧。\n结婚、交往：全部和好结果有关吧。",
            "吉\n枯木逢春艳\n芳菲再发林\n云间方见月\n前遇贵人钦\n枯木逢春艳\n就算是枯木也会在春天开出美丽的花朵般地，人生就算是在严长的冬天裡的辛劳，有一天会得到回报吧。\n芳菲再发林\n像是草花再次盛开，气味也充满林间般地，幸运再次来的时节吧。\n云间方见月\n像是云散可以看见明月般地，各式各样的困难或痛苦之间，幸运会到来吧。\n前遇贵人钦\n善人（神佛、人生的前辈）的引导，渐渐地喜事增加吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：没有阻碍吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "吉\n腊木春将至\n芳菲喜再新\n鲲鲸兴巨浪\n举钩禄为真\n腊木春将至\n像是冬天枯萎的树木也会有花开的春天接近般地，人生的苦难也结束，慢慢地运气会到来吧。\n芳菲喜再新\n像是如果春天来了的话草木也发新芽，吐芬芳，开满花般地，能发挥才能吧。\n鲲鲸兴巨浪\n让人看到大鱼变成大鸟，掀起大波浪的气势，去推动事情吧。\n举钩禄为真\n像是如果要钓鱼的话就能大丰收般地，因为穷究真正的道路，你成功的时候也会到来吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：迟迟才出现吧。\n盼望的人：迟吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都和好结果相连吧。",
            "吉\n射鹿须乘箭\n故僧引路归\n遇道同仙籍\n光华映晚晖\n射鹿须乘箭\n就像拉弓瞄准，就能按照所想地射中鹿一样，自己的行为直接连向成功的方向吧。\n故僧引路归\n像被良好的引导引领般地，能得到良好的居上位者援助和意见吧。\n遇道同仙籍\n因为遵从有智慧的人的教导，能够得到出人头地的喜悦吧。\n光华映晚晖\n像是花在夕阳的照耀下，越来越闪耀般地，在周围的人对你的评价变高了吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：变迟才出现吧。\n盖新居、搬家：没有障碍吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "末吉\n先损后有益\n如月之剥蚀\n玉兔待重生\n光华当满室\n先损后有益\n即使开始的时候损失，后来一定能得到利益的，有令人高兴的事吧。\n如月之剥蚀\n就算月亮变小，也会再变大，变回原来的满月般地，虽然希望变薄弱了，但后来能被实现吧。\n玉兔待重生\n虽然变成日食或月食的话，世界就变得黑暗，但是时间经过，马上就回到原来的状况。灾难也随时间过去，愿望会实现吧。\n光华当满室\n月亮的光芒（希望）照进家中，变得明亮般地，充满欢喜吧。\n愿望：稍后会实现吧。\n疾病：虽然拖长，但可以治癒吧。\n遗失物：难出现吧。\n盼望的人：迟迟地才出现吧。\n盖新居、搬家：应该先放弃，暂时多观察情况再说吧。\n旅行：途中，似乎会有不好的事吧。\n结亲缘、喜庆、交往：不好吧。",
            "半吉\n阴靉未能通\n求名亦未逢\n幸然须有变\n一箭中双鸿\n阴靉未能通\n就像乌云又厚又长，分不清东西般地，心裡迷惘，现在愿望还无法上达天听吧。\n求名亦未逢\n虽然祈求名闻人世间，但是现在还没遇到机会吧。\n幸然须有变\n可是心中的痛苦离去，运势展开，变得幸福的日子会来了吧。\n一箭中双鸿\n像是用一支箭射中两隻鸟般地，好事似乎接踵而来。\n愿望：难以实现吧。\n疾病：变成迟迟地才好转吧。\n遗失物：变成迟迟地才出现吧。\n盼望的人：变成迟迟地才出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：往后一点好吧。",
            "半吉\n月照天书静\n云生雾彩霞\n久想离庭客\n无事惹咨嗟\n月照天书静\n像是天空没有阴霾明显地能看见月亮般地，没有迷惘，澄淨的心吧。\n云生雾彩霞\n但是，至今为止看到的月亮也有云霭，心裡也产生迷惘吧。\n久想离庭客\n和亲密的友人分别，暂时心沉浸在悲伤的思绪中吧。\n无事惹咨嗟\n虽然没事，但是却因为担心悲叹的事很多，转换心情吧。\n愿望：难实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：不好也不坏吧。\n旅行：先放弃，暂时观察情况再说吧。\n结婚、交往：先放弃，暂时观察情况吧。",
            "凶\n望用方心腹\n家乡被火灾\n忧危三五度\n由损断头财\n望用方心腹\n就算有愿望也只是心裡想想而已，还没到达要付诸行动吧。\n家乡被火灾\n像有家裡烧起来般地灾难，接踵而来的危险。\n忧危三五度\n悲伤或危险的事再次地持续发生吧。\n由损断头财\n因为有失去和生命一样重要的东西的可能，要小心谨慎吧。\n愿望：难以实现吧。\n疾病：又坏又危险吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：避开比较好吧。\n旅行：不好吧。\n结婚、交往：招致坏结果吧。",
            "末小吉\n中正方成道\n姦邪恐惹愆\n壶中盛妙药\n非久去烦煎\n中正方成道\n正因为什么事都不偏颇的中正之道的正确行为，能够消除灾难吧。\n姦邪恐惹愆\n一有邪念的话就会被引入坏的方向而去吧。\n壶中盛妙药\n就像是在药箱中先存放着有效的药般，不迷失去自己地珍惜真诚心吧。\n非久去烦煎\n这样做的话烦恼就会离去，灾难会消去吧。\n愿望：难以立刻地实现吧。\n疾病：虽然拖长但会治好吧。\n遗失物：会出现吧。\n盼望的人：变成迟迟才地出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：不好也不坏吧。",
            "末吉\n有物不周旋\n须防损半边\n家乡烟火裡\n祈福始安然\n有物不周旋\n虽然有很多东西但是难到手的状况。虽然希望很丰富，但是难以实现吧。\n须防损半边\n成功一半，损失一半吧。但是不要坚持小事，想着一半已经成功事吧。\n家乡烟火裡\n有火灾发生的危险。要充分地注意吧。\n祈福始安然\n相信神明或佛菩萨，如果抱着坚定的心，最后会变得安泰吧。\n愿望：难以实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：变成迟迟地才出现吧。\n盖新居、搬家：不好吧。\n旅行：途中似乎有不好的事。\n结婚、交往：会产生不好的结果吧。",
            "吉\n桂华春将到\n云天好进程\n贵人相遇处\n暗月再分明\n桂华春将到\n像是桂花在春天飘香般地，对你也变成是运势展开的时机吧。\n云天好进程\n人也转运的话，有得到崇高的地位与荣誉的机会。\n贵人相遇处\n有观世音菩萨或有力人士的引导吧。\n暗月再分明\n如阴天的月亮放晴般地，越来越会发生好事吧。\n愿望：会实现吧。\n疾病：会治癒吧。\n遗失物：会出现吧。\n盖新居、搬家：好吧。\n盼望的人：变成迟迟地才出现吧。\n旅行：好吧。\n结婚、交往：全都会变成好结果吧。",
            "吉\n月桂将相满\n追鹿映山溪\n贵人乘远箭\n好事始相宜\n月桂将相满\n就像月缺不久将变成满月般地，好运全盛的时期正在接近了。\n追鹿映山溪\n鹿就是禄。也就是说，虽然现在还没得到崇高的地位和收入，但是有将来会得到的命运。\n贵人乘远箭\n箭就是弓箭。应该要尊敬的人从远方乘箭而来的援助之暗示是表示着如果学习这个人的善行而做的话，表示能得到崇高地位与收入。\n好事始相宜\n愿望开始实现，名声被好好地知道，会变得幸福吧。但是切忌高傲自满。\n愿望：会实现吧。\n疾病：虽然拖长但是会治好吧。\n遗失物：难出现吧。\n盼望的人：变成迟迟地才出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：变成好结果吧。",
            "吉\n盘中黑白子\n一着要先机\n天龙降甘泽\n洗出旧根基\n盘中黑白子\n就像在下围棋当中的输赢一样，人生的吉或凶也还没确定吧。\n一着要先机\n胜负的事或人生都是要取得先机比什么都还重要吧。区别善恶，如果是善道的话，笔直地着向善道而去是好的吧。\n天龙降甘泽\n神明或佛菩萨会降下甘露（恩惠）的援助吧。\n喜出旧根基\n用甘露水洗去过去的罪恶般地，清澈地，变成可以发挥本来的能力吧。\n愿望：会实现吧。\n疾病：会治癒吧。\n遗失物：会出现吧。\n盼望的人：变成迟迟地才出现吧。\n盖新居、搬家：没问题吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "吉\n有意兴高显\n禄马引前程\n得遇云中箭\n芝兰满路生\n有意兴高显\n受到别人的信赖，得到名声，变成能够累积财富吧。\n禄马引前程\n如果能一直保持着善心的话，在将来的人生幸运会成为你的嚮导吧。\n得遇云中箭\n因为令人感谢的神佛的加护，会遇到幸运吧。\n芝兰满路生\n如药草或香草一片茂盛般地，被好人包围，名声在世间被知道，能够变得幸福吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：迟迟地才出现吧。\n盼望的人：变迟迟地才出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都好结果相连吧。",
            "凶\n雷发震天昏\n佳人独掩门\n交加文书上\n无事也遭迍\n 雷发震天昏\n在乌云裡雷声响遍，变得像是要震撼天地般地，是非常令人担心的状况。\n佳人独掩门\n少女独自一人，没和人交流，孤单地的状况。要时时警戒吧。\n交加文书上\n在合约等事情，似乎会发生错误或诉讼。\n无事也遭迍\n虽然说如果诚心诚意地小心谨慎的话比较好，但是过度信任自己的才能，打算做什么行动的话就全部会变成为凶。\n愿望：难以实现吧。\n疾病：会治好吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：现在放弃吧。\n旅行：在途中有不好的事吧。\n结婚、交往：会产生不好的结果吧。",
            "吉\n更望身前立\n何期在晚成\n若遇重山去\n财禄自相迎\n更望身前立\n虽然为了早点实现愿望似乎一直期待着，但是不可以过度着急。\n何期在晚成\n像是大器晚成般地，延长志气，扩大心胸，不焦急慢慢地等待成功吧。\n若遇重山去\n重山是一山又一山的意思。因为辛苦地越过人生的山坡，希望也变得可以实现。\n财禄自相迎\n必定会成功吧。财产和地位也变得可以到手吧。\n愿望：会实现吧。\n疾病：变成往后才会治好吧。\n遗失物：会出现吧。\n盼望的人：变得迟迟才出现吧。\n盖新居、搬家：好吧。\n旅行：在将来似乎有好事吧。\n结婚、交往：全部都可得到好结果吧。",
            "小吉\n见禄隔前溪\n劳心休更迷\n一朝逢好渡\n鸾凤入云飞\n见禄隔前溪\n像是隔着山谷看得见宝物般地，就算想要的东西就在眼前，似乎也难得到吧。\n劳心休更迷\n勉强地想得到那个财宝，会使心裡迷惘，放弃吧。\n一朝逢好渡\n就这样用平常心按照平日的生活吧。如果时机来的话，自然会得到财宝。\n鸾凤入云飞\n有居上位者或认识的人的援助吧。像凤凰飞向天空般地，会出人头地，好事会来临吧。\n愿望：如果一直抱持着正直的心的话，到后来能被实现吧。\n疾病：虽然拖长，但将来会治好吧。\n遗失物：会出现吧。\n盼望的人：变成迟迟才来吧。\n盖新居、搬家：虽然开始不好，但是到后来会变好吧。\n结婚、交往、旅行：马马虎虎吧。",
            "吉\n正好中秋月\n蟾蜍皎洁间\n暗云知何处\n故故两相攀\n正好中秋月\n像是十五号的夜晚，没有月缺，又圆又明亮的月亮般地，运气非常好吧。\n蟾蜍皎洁间\n就像因为月亮皎洁，住在裡面的兔子和蟾蜍能清楚看见般地，展现洁淨的心和光辉吧。\n暗云知何处\n像是天空一点云都没有，万里晴空般地，没有妨碍的东西，心中也没有迷惘吧。\n故故两相攀\n整个天空没有云般地，心中没有比这个更澄淨的吧。\n愿望：会实现吧。\n疾病：严重吧。\n遗失物：难出现吧。\n盼望的人：变成迟迟才出现吧。\n盖新居、搬家：马马虎虎吧。\n旅行：好吧。\n结婚、交往：马马虎虎吧。",
            "吉\n有达宜更变\n重山利政逢\n前途相偶合\n财禄保亨通\n有达宜更变\n为了达成事情，要好好地理解那件事的内容，边改进以前的方法，边向前进吧。\n重山利政逢\n如果山重迭的话，成为出这个字。已经下了使事情达成的决心的话，从现在的地方起飞展开行动吧。\n前途相偶合\n这么做的话，在将来自然而然地能遇见幸福吧。\n财禄保亨通\n再来，财宝也从一开始到结束确实地能得到吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：变迟吧。\n盖新居、搬家：好吧。\n旅行：成为好的旅行吧。\n结婚、交往：成为好的结果吧。",
            "吉\n修进甚功辛\n劳生未得时\n腾身游碧汉\n方得遇高枝\n修进甚功辛\n虽然没有懒惰，好像一直勤劳努力，但是现在只感觉到辛苦吧。\n劳生未得时\n因为有大大的愿望，虽然拼命地努力，但是似乎还没到花开的时期吧。\n腾身游碧汉\n然而，看着天空，抱着打算一飞向上的大决心，认真地挑战看看吧。\n方得遇高枝\n确实地能得到资产和财宝、出人头地等，能安心吧。\n愿望：会实现吧。\n疾病：变成往后才治好吧。\n遗失物：难出现吧。\n盼望的人：变晚吧。\n盖新居、搬家：好吧。\n旅行：好事吧。\n结婚、交往：会得到好结果吧。",
            "凶\n有僭须惹讼\n兼有事交加\n门裡防人危\n灾临莫叹嗟\n有僭须惹讼\n身上发生错误的事，被人控诉，引起争讼吧。\n兼有事交加\n这个争讼之外，还有一件难以解开的困难争执的事吧。\n门裡防人危\n原因之一是亲戚或家人包含在其中，从这件事解决后，可以防止灾难吧。\n灾临莫叹嗟\n就算有灾难也不要叹气，帮助你的人会出现吧。\n愿望：难实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：马马虎虎还算有点好吧。\n旅行：因为不好，避开吧。\n结婚、交往：不好也不坏吧。",
            "吉\n久困渐能安\n云书降印权\n残花终结实\n时亨禄自迁\n久困渐能安\n长时间的劳苦终于溶化不见，渐渐地变好吧。\n云书降印权\n从居上位者能得到好的资格（身份、或职位）或权力吧。\n残花终结实\n像是残存的花朵结成果实般地，终于运气来了吧。\n时亨禄自迁\n变得能自由地得到福德，并且高昇，到最后都幸福吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：变得迟迟才找到吧。\n盼望的人：迟迟地才出现吧。\n盖新居、搬家：好吧。\n旅行：变成好的旅行吧。\n结婚、交往：全都朝向好的方向发展吧。",
            "凶\n身同意不同\n月蚀暗长空\n轮虽常在手\n鱼水未相逢\n身同意不同\n只是着急，不能分出好坏吧。\n月蚀暗长空\n像月食般地，渐渐起乌云，变得笼罩在黑暗般地状态吧。\n轮虽常在手\n虽然有车但是目的地没决定般地，就算好事在眼前，也没办法得到的状态吧。\n鱼水未相逢\n像是鱼没遇到水就会死亡般地，如果和周围的人没办法心意相通的话，什么是都没办法做成的。经常顺应这个世界、心情平静的态度是很重要的。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：暂时放弃，再观察看看吧。\n结婚、交往：变成坏结果吧。",
            "吉\n云散月重明\n天书得志诚\n虽然多阻滞\n花发再重荣\n云散月重明\n像遮蔽月亮的云散去，变得更加明亮般地，被关闭的心云放晴，还变成很澄淨的心吧。\n天书得志诚\n像月亮或星星闪耀美丽光辉般地，人心也澄清，妨碍的事物也消失不见吧。\n虽然多阻滞\n就算有阻碍或困难，没有到变成痛苦的程度吧。\n花发再重荣\n变成再度繁盛的状态，子孙也会繁荣吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会找到吧。\n盼望的人：变迟吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "末小吉\n生涯喜又忧\n未老先白头\n劳心千百度\n方遇贵人留\n生涯喜又忧\n像是如果有喜事的话也会有悲伤的事般地，吉凶轮流来吧。\n未老先白头\n虽然还没到那个年龄，但长出明显易见的白髮，是因为操心的事很多吧。\n劳心千百度\n会遇到好几次重迭而来的劳苦吧。\n芳遇贵人留\n但是得到观世音菩萨或居上位者的帮助，得到力量，最后变得幸福吧。\n愿望：难实现吧。\n疾病：变成迟迟才治好吧。\n遗失物：会出现吧。\n盼望的人：迟迟才出现吧。\n盖新居、搬家：半吉吧。\n旅行：如果有一起同行的人的话好（安全）吧。\n结婚、交往：马马虎虎还可以吧。",
            "吉\n欲渡长江阔\n波深未自俦\n前津逢浪静\n重整钩鳌钩\n欲渡长江阔\n像是虽然想要渡过长长的河川，幅宽太宽难渡过般地，就算想要达成事物，困难很多吧。\n波深未自俦\n像是波涛凶勐、没有船，难渡河般地，也变成达成困难的状态吧。\n前津逢浪静\n所以在波浪平静、容易渡河的时候到来为止，静静地等待吧。\n重整钩鳌钩\n一度冷静之后，如果是准备好钓钩的你的话，就能得到能钓大鱼的契机吧。这样得到幸运的机会会到来吧。\n愿望：会实现吧。\n疾病：虽然会治好，但会拖长吧。\n遗失物：会出现吧。\n盼望的人：变迟迟才出现吧。\n盖新居、搬家：好吧。\n旅行：坏吧。\n结婚、交往：马马虎虎还可以吧。",
            "凶\n有径江海隔\n车行峻岭危\n亦防多进退\n犹恐小人亏\n有径江海隔\n即使有想要走的道路，就像遇到海或河的阻隔般地，要实际执行事情，有各式各样的困难吧。\n车行峻岭危\n像是押着车向险峻的山走去，似乎有非常大的困难。不能粗心大意。\n亦防多进退\n无论向前进、往后回都没有办法的困难的事情吧。要小心吧。\n犹恐小人亏\n有会进行阻碍的人，坏的时候，坏事接踵而来。要经常小心吧。\n愿望：难实现吧。\n疾病：不能安心吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：中止吧。\n结婚、交往、旅行：坏吧。",
            "凶\n去住心无定\n行藏亦未宁\n一轮清皎洁\n却被黑云乘\n去住心无定\n有飘移不定的心，没有决定（没有决心）吧。\n行藏亦未宁\n只是对事物迷惘，充满各种不安吧。\n一轮清皎洁\n虽然心中的明月清澈，明亮地闪耀光辉，\n却被黑云乘\n但被迷惘的乌云覆盖，仅仅一点点的未来也不能看见吧。快点除去迷惘的云，取回原本的心吧。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：似乎会发生坏事吧。\n结婚、交往：得到坏结果吧。",
            "小吉\n高危安可涉\n平坦是延年\n守道当逢泰\n风云不偶然\n高危安可涉\n就像是高处的风很强般地，过于引人注目反而过得不安稳。\n平坦是延年\n正因为平凡的生活，才是长寿或安乐的方法。\n守道当逢泰\n如果能守着这样的生活方式，会是安泰又平和吧。\n风云不偶然\n这样的诚实的生活必定会得到上天的恩惠吧。\n愿望：如果正心而行的话会实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：不好吧。\n旅行：马马虎虎地算好吧。\n结婚、交往：马马虎虎地算好吧。",
            "半吉\n旧愆何日解\n户内保婵娟\n要逢十一口\n遇鼠过牛边\n旧愆何日解\n变成担心过去的错误何时才能消失吧。\n户内保婵娟\n家裡加入美人，这件事想向世人公布就是没有反省自己的生活与没有节操，用心在家裡和睦吧。\n要逢十一口\n如果试着将十一和口重迭起来看的话，会变成吉字。也就是说，如果期望吉事而努力做的话，必定会到来吧。\n遇鼠过牛边\n像是在人们沉静入睡的夜晚也起床工作般地努力吧。\n愿望：难实现吧。\n疾病：会拖长吧。\n遗失物：难找到吧。\n盼望的人：变迟吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：不好吧。",
            "大吉\n灾轗时时退\n名显四方扬\n改故重乘禄\n昴高福自昌\n灾轗时时退\n灾难也慢慢地消失，运势会展开来吧。\n名显四方扬\n名声慢慢地传遍世间，就好的意义看，不知道的人也变得不存在吧。\n改故重乘禄\n能改去过去的事，名声和实际都能得到幸运吧。\n昴高福自昌\n出人头地，变得福运繁荣，会繁盛吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：没问题吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "凶\n何故生荆棘\n佳人意渐疏\n久困重轮下\n黄金未出渠\n何故生荆棘\n理由也一直不知道地，家中产生问题吧。\n家人意渐疏\n家人或夫妇之间心意无法相通吧。\n久困重轮下\n不反省原因的话就会像被埋在重重地车轮底下般地，变得长期间地辛劳吧。\n黄金未出渠\n因为玩乐失去财产，一直无法回复。请努力忠于自己的本分吧。\n愿望：难实现吧。\n疾病：难治癒吧。\n遗失物：难找到吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：似乎会发生坏事吧。\n结婚、交往：会产生坏结果吧。",
            "凶\n安居且虑危\n情深主别离\n风飘波浪急\n鸳鸯各自飞\n安居且虑危\n就算是似乎安乐，心裡也还留着忧虑吧。\n情深主别离\n和感情深厚的人也有可能会发生离别的悲伤的事。\n风飘波浪急\n这简直是风强浪大般的状况啊。\n鸳鸯各自飞\n虽然鸳鸯不分离地飞行，但是飞向分离的命运。静静地等待吧。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：不会出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：还可以吧。\n旅行：还可以吧。\n结婚、交往：不好吧。",
            "末吉\n苦病兼防辱\n乘危亦未稣\n若见一阳后\n方可作良图\n苦病兼防辱\n觉得内心的痛苦和受人侮辱，不安稳吧。\n乘危亦未稣\n就像面临危险的人还没完时甦醒般地，这个困难没有那么简单地解决。\n若见一阳后\n如果春天来了的话（如果能有观世音菩萨的慈悲光辉的话）也会有好事吧。\n方可作良图\n从好事开始发生起，请立定计画开始行动。到好事开始为止请静静地忍耐。\n愿望：以后会实现吧。\n疾病：虽然拖长但会治好吧。\n遗失物：不会出现吧。\n盼望的人：变得迟迟才出现吧。\n盖新居、搬家：好吧。\n旅行：安全吧。\n结婚、交往：得到还可以的好结果吧。",
            "凶\n水滞少波涛\n飞鸿落羽毛\n重忧心绪乱\n闲事惹风骚\n水滞少波涛\n水淤塞、浪不起可说是物质、精神贫乏、也没有办法从事社会活动的状态。\n飞鸿落羽毛\n就像是羽毛掉落，变成无法飞行的鸟般地，失去重要的东西，没办法生活吧。\n重忧心绪乱\n悲伤的事接连而来，心思溷乱，方法用尽不知如何是好吧。\n闲事惹风骚\n就算想待在安静的地方，也会有引来大问题吧。\n愿望：难实现。\n疾病：可疑，不明朗吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：坏吧。",
            "凶\n枯木未生枝\n独步上云岐\n岂知身未稳\n独自惹闲非\n枯木未生枝\n变成枯木，枝干上没有长叶子，似乎现在还没有迎接春天般地，\n独步上云岐\n就算要有执行不会实现的愿望，心中只是越来越烦恼而已。\n岂知身未稳\n不瞭解自己的身份、地位，就要有所行动，是无法安稳的。要有信心，要举止谨慎吧。\n独自惹闲非\n不悔悟自己的到前几日为止错误，以后就会后悔吧。\n愿望：难实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：多比较看看比较好吧。\n旅行：不好吧。\n结婚、交往：坏吧。",
            "吉\n异梦生英杰\n前来事可疑\n芳菲春日暖\n依旧发残枝\n异梦生英杰\n生出优秀的人、做好梦是因为神佛加持庇护的幸运到来的暗示。\n前来事可疑\n虽然得到这个幸福，但和昨天的自身相比较，却难以置信吧。\n芳菲春日暖\n像春天变温暖，飘散蔬菜花的香味般地，幸福来临。\n依旧发残枝\n枯了的树木也会开花般地，似乎会发生可喜可贺的事。只是，自重自爱是非常重要的。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出来吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "凶\n明月暗云浮\n花红一半枯\n惹事伤心处\n行舟莫远图\n明月暗云浮\n明亮的月亮也被乌云遮住，变为不晴朗的状态吧。\n花红一半枯\n像是红花有一半枯掉般地，运气也变成走下坡。\n惹事伤心处\n虽然打算努力做事，也尽是心痛、担心吧。\n行舟莫远图\n像要乘船等出去远方的大希望，无法渡过般地，谨慎地等待时机到来吧。\n愿望：难实现吧。\n疾病：切忌粗心大意。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：放弃吧。\n结婚、交往：坏吧。",
            "凶\n雷发庭前草\n炎火向天飞\n一心来赶禄\n争奈掩朱扉\n雷发庭前草\n雷落在自家的庭前是由于身份低下或雇用的人引发灾祸。\n炎火向天飞\n像是火焰向天飞去般地，上下关係变得不合，有争执吧。\n一心来赶禄\n一心一意想要得到利益但没办法实现。\n争奈掩朱扉\n至少要重视雇用的人或下属等，防止灾难发生吧。\n愿望：难实现吧。\n疾病：不能安心吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：避免吧。\n结婚、旅行、交往：万事坏吧。",
            "凶\n道业未成时\n何期两不宜\n事烦心绪乱\n飜做徘徊思\n道业未成时\n因为心裡和工作的实力都还没成熟，现在是学习的时期。\n何期两不宜\n因为心裡和工作的实力都还没成熟，就算想做什么也无法按照所想地顺利进行吧。\n事烦心绪乱\n因为这样的事，引起各种麻烦，令人厌烦的痛苦和溷乱吧。\n飜做徘徊思\n没办法好好地想事情，只是晃来晃去心情不定吧。需要反省。\n愿望：难实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n结婚、旅行、交往：产生坏的结果吧。",
            "吉\n户内防重厄\n花菓见分枝\n严霜纔过后\n方可始相宜\n户内防重厄\n家中恐怕有灾祸到来。但是，为了防止发生，要小心吧。\n花菓见分枝\n枝干各自分开是说家庭不合。因为这个缘故全部都不和睦吧。\n严霜纔过后\n相互地悔改坏的地方，然后战胜这的试炼。如果这样做的话，似乎会以好事发生。\n方可始相宜\n因为家裡和睦，好事似乎越变越多。\n愿望：后来会实现吧。\n疾病：会拖长吧。\n遗失物：变成迟迟才能找到吧。\n盼望的人：迟迟才出现吧。\n盖新居、搬家：还算好吧。\n旅行：没有特别的阻碍吧。\n结婚、交往：虽然还算好，但最后变得更好吧。",
            "吉\n久暗渐分明\n登江绿水澄\n芝书从远降\n终得异人成\n久暗渐分明\n久佈乌云的天空也终于放晴，很畅快吧。幸运似乎会到来。\n登江绿水澄\n水或树木都澄淨明朗，也变得没有要担心的事吧。\n芝书从远降\n因为得到居上位者的推荐，出人头地吧。\n终得异人成\n被神佛帮助，得到好结果吧。要有信心是很重要的。\n愿望：变得往后才能被实现吧。\n疾病：会治好吧。\n遗失物：会出来吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "凶\n蛇虎正交罗\n牛生二尾多\n交岁方成庆\n上下不能和\n蛇虎正交罗\n因为不知道蛇或虎溷杂等的道理，会发生坏事。\n牛生二尾多\n牛加上两条尾巴的话，就变成失这个字。说不定会有什么损失。\n交岁方成庆\n虽然随着年龄增加透过交流，有令人高兴的事，但是却往往常有各种争夺、争吵的事。\n上下不能和\n因为家裡不和睦而不会平静。用温和的心领会忍耐吧。\n愿望：难以实现吧。\n疾病：不能安心吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n结婚、旅行、交往：坏吧。",
            "凶\n孤舟欲过岸\n浪急渡人空\n女人立流水\n望月意情浓\n孤舟欲过岸\n一艘小船想要航向遥远的对岸，会是没有帮忙的人的状态。\n浪急渡人空\n因为水流急，要渡河是过度危险的事，所以是虚幻的心情。各种障碍滚滚而来，什么事都困难的吧。\n女人立流水\n柔弱的女性一人站在急流处，是非常危险的。虽然想为她作些什么但是处于无可奈何的状态。\n望月意情浓\n相对于自己的担心，非常羡慕他人的安乐吧，但是要反省自己的行为，竭尽地拜託神佛，防止灾难发生吧。\n愿望：难实现吧。\n疾病：陷入的话（若是病人的话）危险吧。\n遗失物：不能找回来吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：坏吧。",
            "吉\n富贵天之祐\n何须苦用心\n前程应显迹\n久用得高临\n富贵天之祐\n得到财产、地位变高是上天赐给的东西。\n何须苦用心\n就算用尽心思与痛苦，没有神佛的帮忙的话，不能实现吧。\n前程应显迹\n前程的好坏是根据至今为止所做的行为的好坏而来的吧。\n久用得高临\n长时间实行正道、彻底行善等等的话，地位会变高，财宝也能得到吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出来吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全部都好吧。",
            "凶\n累滞未能稣\n求名莫远图\n登舟波浪急\n咫尺隔天衢\n累滞未能稣\n万事不能顺利进行会接连而来，看不到前景吧。\n求名莫远图\n现在不能想要名声广播、祈求幸福等。\n登舟波浪急\n想要乘船而去，但浪高难以渡过吧。\n咫尺隔天衢\n虽然愿望好像快要实现，但是被灾难阻挡。结果的差别像天和地般地不一样的状况。请自重，等待时机的到来吧。\n愿望：难实现吧。\n疾病：不能安心吧。\n遗失物：难找到吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：坏吧。",
            "大吉\n但存公道正\n何愁理去忠\n松柏苍苍翠\n前山禄马重\n但存公道正\n守着公共的正道，比起为了自己，更要为了大家做好事吧。\n何愁理去忠\n忠实地尽心尽力做事，就算这样反而事情不能顺利进行、立场变坏也要当作没有悲伤叹息的事吧。\n松柏苍苍翠\n就像松树或柏树经常青翠般地，人的心也要注意要经常走在诚恳的道路吧。\n前山禄马重\n到最后会有好事，福德像是满出来般地变得幸福吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出来吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "吉\n残月未还光\n樽前非语伤\n户中有人厄\n祈福保青阳\n残月未还光\n像是明亮的月光还没衰退、光辉闪耀着般地，你也随着上年纪越来越能活跃。\n樽前非语伤\n就像是就算喝酒，一点点也不会溷乱般地，什么坏事都没做，\n户中有人厄\n但是，家中稍微有灾难吧。\n祈福保青阳\n如果怀着信心，期祷幸福的话，像是温暖的日光照射的春天般地，心变得安定、安泰吧。\n愿望：虽然能被实现但是大愿望不行吧。\n疾病：虽然会拖长，但会治好吧。\n遗失物：迟迟地才找到吧。\n盼望的人：变迟才出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "大吉\n深山多养道\n忠正帝王宣\n凤遂鸾飞去\n昇高过九天\n深山多养道\n险恶的修行是要穷究真诚之道吧。\n忠正帝王宣\n忠诚的心被认同、居上位者派人过来，变成大大地出人头地吧。\n凤遂鸾飞去\n凤凰也是鸾也是，是出现在正确的人世间的鸟。是可喜可贺的象徵。\n昇高过九天\n飞越极高的天空，还登上比这样更高吧。因为努力，高高的目标陆陆续续地能达成吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：是好的，因为全部都保持谦虚的姿态，所以会招来好结果吧。",
            "小吉\n道合须成合\n先忧事更多\n所求财宝盛\n更变得中和\n道合须成合 \n如果自身的行为符合道理的话，什么都会成功吧。\n先忧事更多\n但是在最初的时候悲伤和痛苦会很多吧。\n所求财宝盛\n之后，所希望的财宝会如心想地聚集过来吧。\n更变得中和\n未来的灾难也会马上变成往幸福的方向，繁盛会到来吧。\n愿望：如果保持端正的心的话，会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "凶\n火发应连天\n新愁惹旧愆\n欲求千里外\n要渡更无船\n火发应连天\n有天井也烧焦般的大火是因为慾望或怒气而不能安稳的意思。\n新愁惹旧愆\n新的悲伤或痛苦、然后旧伤痕等被拿出来，令人担心的事很多吧。\n欲求千里外\n就算想逃到远处但是相当地困难吧。\n要渡更无船\n前往的目的地有大河，就算想渡河而过但没有船会相当辛苦。暂时保持现状吧。\n愿望：难实现吧。\n疾病：可疑，不明朗吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：多比较看看比较好吧。\n结婚、交往：全都坏吧。",
            "凶\n举步出云端\n高枝未可攀\n昇头看皎月\n犹在黑云间\n举步出云端\n想抬脚乘云登天，却不能登天。高高的愿望是没有用的事。\n高枝未可攀\n想爬上高高的树枝，但是抓得到的树枝，像是没有比这个更高的一样，自己的生活不安，也没有援助吧。\n昇头看皎月\n抬头看天空，就算想看见晴朗的月亮，\n犹在黑云间\n自己想看的月亮还隐藏在云中，不能好好看见。安静地端正行为吧。\n愿望：难实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：危险吧。\n结婚、交往：产生坏结果吧。",
            "凶\n否极方无泰\n花开值晚秋\n人情不调备\n财宝鬼来偷\n否极方无泰\n八方堵塞，没有畅通的道路吧。\n花开值晚秋\n虽然花会开但是受晚秋般地冷风吹拂，立刻就枯萎了吧。\n人情不调备\n各自为了自己的主张，人情心也不一致，抱怨不停吧。\n财宝鬼来偷\n储存的宝物或财产也因魔鬼出现偷走，财产渐渐地减少，于是变得贫穷吧。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：不好吧。\n结婚、交往：全部都产生坏的结果吧。",
            "大吉\n望用何愁晚\n求名渐得宁\n云梯终有望\n归路入蓬瀛\n望用何愁晚\n虽说愿望很晚才会实现，不悲伤叹息慢慢地等待吧。\n求名渐得宁\n渐渐地名声扬起，变成安心的心情吧。\n云梯终有望\n大大的愿望也得到援助，终于能被实现吧。\n归路入蓬瀛\n变成能得到福德、财产、长寿吧。\n愿望：变成往后才会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "大吉\n花发应阳台\n车行进宝财\n执文朝帝殿\n走马听声雷\n花发应阳台\n像是从照到阳光的房屋，可以充分地看见花盛开的景象般地，一切都能如愿地充分被能实现吧。\n车行进宝财\n像是堆满财宝的车子来到自己的家般地，财产或宝物变得丰富吧。\n执文朝帝殿\n显现学问的德行，被居上位者带领，还让你能说出愿望吧。\n走马听声雷\n得意洋洋地骑马，那种姿态是变成成令人羡慕的身份吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全都好吧。",
            "大吉\n凿石方逢玉\n淘沙始见金\n青霄终有路\n只恐不坚心\n凿石方逢玉\n偶然挖出石头中的宝石可说是遇见没想过的幸福。\n淘沙始见金\n就像是淘砂收集金子般地，在生活中财宝自然地累积吧。\n青霄终有路\n想向天空实现大成功之道，在世间也广为称讚吧。\n只恐不坚心\n只是，如果不意志坚定一心努力的话，什么是都不能成功吧。\n愿望：能被实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n结婚、交往：好吧。",
            "凶\n作事不和同\n临危更主凶\n佳人生苦根\n闲虑两三重\n作事不和同\n就算想做些什么事，却和人或者夫妇之间是不和睦的状态。\n临危更主凶\n因为在这样的状态下，就算想从危险的事逃离、防止危险的事，坏事还是发生吧。\n佳人生苦根\n产生像是关係到自己的妻子般的痛苦或担心的事。\n闲虑两三重\n坏事一而再再而三地接踵发生。要非常有信心吧。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：不会出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：坏吧。",
            "大吉\n一片无瑕玉\n从今好琢磨\n得遇高人识\n方逢喜气多\n一片无瑕玉 \n玉石因为琢磨终于变成无瑕疵的玉是世上天赐给的东西。\n从今好琢磨 \n就像天生的好人也因凋琢的方式不同变成更好的人般地，诚心地更加努力吧。\n得遇高人识 \n这样做的话会被名声高的人赏识，变成能得到提拔吧。\n方逢喜气多 \n智慧或财宝充满，被无限的欣喜包围的时机会机到来吧。\n愿望：能被实现吧。疾病：会治好吧。\n遗失物：不会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "大吉\n一信向天飞\n秦川舟自归\n前途成好事\n应得贵人推\n一信向天飞\n如果有真诚心的话，最后会传达给上天，出人头地的时候会到来吧。\n秦川舟自归\n因为上天的恩惠，会得到各种财宝吧。\n前途成好事\n将来会遇见好事吧。\n应得贵人推\n因为得到居上位者（菩萨）的力量，能被吸引往好的方向吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全部都好吧。",
            "吉\n改变前途去\n月桂又逢圆\n云中乘禄至\n凡事可宜先\n改变前途去 \n如果改进到现在为止坏事，崭新地向前进的话，事情会改变的吧。\n月桂又逢圆 \n就像缺月也会再变圆般地，吉事就犹如月的圆缺。至今为止的缺点也会渐渐地变好吧。\n云中乘禄至 \n从天降下来福德、幸运吧。\n凡事可宜先 \n在做任何事时，也不要落于人后，先做就能得到好结果吧。\n愿望：如果守正道的话会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "吉\n自幼常为旅\n逢春骏马骄\n前程宜进步\n得箭降青霄\n自幼常为旅 \n从小时候起的到流落旅行就是内心的不安定，劳苦很多。\n逢春骏马骄 \n如果变成春天的话，就像马也振奋地来回奔跑般底，终于运气到来吧。\n前程宜进步 \n就算如心想地去了哪裡，会变成如自己想的一样吧。\n得箭降青霄 \n箭笔直地向前进时是要射中猎物。从天而来的幸运向你而来吧。\n愿望：会实现吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "吉\n有鱼临旱池\n跳跃入波涛\n隔中须有望\n先且虑尘劳\n有鱼临旱池 \n虽然有很多鱼但是池子裡如果没有水会死掉吧。如果没有保持着真诚心的话，人总有一天会向灭绝而去吧。\n跳跃入波涛 \n就像是在没水池子裡的鱼如果进入广大的河川的话，也生气勃勃般地，你的运势也终于到来了吧。\n隔中须有望 \n但是因为有阻碍，要十分注意吧。暂时忍耐吧。\n先且虑尘劳 \n因为忍耐，来生、后世或子孙能幸福吧。\n愿望：变成到后来能实现吧。\n疾病：会拖长吧。\n遗失物：难出现吧。\n盼望的人：变迟吧。\n盖新居、搬家：马马虎虎还算可以吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "半吉\n事忌樽前语\n人防小辈交\n幸乞阴公祐\n方免事敌爻\n事忌樽前语 \n喝酒时说的话是边喝酒边说出的话，不能全部当真。\n人防小辈交 \n避免和比自己低下的人交流吧。应该要避免只说场面话吧。\n幸乞阴公祐 \n好好遵从母亲（神、佛）吧。如果这样做的话，愿望能被实现吧。\n方免事敌爻  \n化解对事物的敌对意识，广泛和人交往吧。渐渐地会变成幸福吧。\n愿望：不能按照所想的实现吧。\n疾病：虽然会拖长但是不会危害生命吧。要特别用心维持健康吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：不好吧。\n旅行：马马虎虎还算可以吧。\n结婚、交往：勉强还算可以吧。",
            "吉\n志气勤修业\n禄位未造逢\n若闻金鸡语\n乘船得便风\n志气勤修业 \n立定志向，如果一心努力的话，渐渐地会朝向好的方向吧。\n禄位未造逢 \n现在就算福运还没到来，必定之后会到来吧。\n若闻金鸡语 \n就像等待着黑夜放明，鸡开始啼叫般地，等待时机的到来吧。\n乘船得便风 \n时机到来、就像风把船推向前进的方向般地，渐渐地朝向幸福的方向吧。 \n愿望：能被实现吧。\n疾病：变成迟迟才治好吧。\n遗失物：变成迟迟地才出现吧。\n盼望的人：迟迟地才出现吧。\n盖新居、搬家：没有阻碍吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "大吉\n鸡逐凤同飞\n高林整羽仪\n棹舟须济岸\n宝货满船归\n鸡逐凤同飞 \n就像鸡一边追着凤凰，也和凤凰一样地飞翔般地，仰赖有地位的人，出人头地吧。  \n高林整羽仪 \n然后，就像停在高高的树林，整理羽毛般地，在和身份高的人交流中能得到幸福吧。\n棹舟须济岸  \n就像船撑篙要渡向对岸一般地，因为自己开始行动，在世间能安心地渡过吧。\n宝货满船归   \n出人头地，就像财宝也很多，堆满船归来般地，约定了幸福。\n愿望：能被实现吧。但是，抱持全面谨慎的心是很重要的。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：全部好吧。",
            "凶\n雾罩重楼屋\n佳人水上行\n白云归去路\n不见月波澄\n雾罩重楼屋 \n就像高高房子也隐于雾中看不见般地，烦恼的事不断，每天昏暗、阴天吧。\n佳人水上行 \n就像柔弱的女性独自一人乘船在水上旅行般地，现在正面临危险的状态。\n白云归去路 \n白云未定，去的方向也不知道。每天不知道会发生什么事吧。\n不见月波澄 \n就像澄清的水应该映着月亮的倒影也因为波浪凶勐看不见般地，种种妨碍很多吧。首先要内心安定是很重要的。\n愿望：难以实现吧。\n疾病：危险吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：不好吧。\n结婚、交往：坏吧。",
            "凶\n欲理新丝乱\n闲愁足是非\n只困罗网裡\n相见几人悲\n欲理新丝乱 \n就像想回复纠缠在一起溷乱的丝线是困难的般地，想要除去心中的痛苦是苦难吧。\n闲愁足是非 \n独自静静地抱着很多烦恼或悲伤，就连事物的善恶也以难发现吧。\n只困罗网裡 \n就像鱼被困在网中身体不能动般地，挣扎会感到痛苦吧。\n相见几人悲 \n自己还有身边的人也悲伤、烦恼的事很多，接踵不断吧。然而如果用信心的去作话，能逃离吧。\n愿望：难以实现吧。\n疾病：可疑，不明朗吧。\n遗失物：难出现吧。\n盼望的人：不会出现吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：坏吧。",
            "大吉\n红日当门照\n暗月再重圆\n遇珍须得宝\n颇有称心田\n红日当门照 \n就像朝阳闪耀照在门前，变得明亮般地，有因上天的恩惠而来的好事吧。\n暗月再重圆 \n到现在为止的黑夜中月亮再度变成满月，普照四周吧。开朗的心情会让周遭和睦、平静吧。\n遇珍须得宝 \n能得到稀奇的财宝吧。\n颇有称心田 \n变得有名，变成心愿实现吧。应该要谨慎粗心大意和骄傲的事。\n愿望：能被实现吧。在万事中要用谦虚的心吧。\n疾病：会治好吧。\n遗失物：会出现吧。\n盼望的人：会出现吧。\n盖新居、搬家：好吧。\n旅行：好吧。\n结婚、交往：好吧。",
            "凶\n禄走白云间\n携琴走远山\n不遇神仙面\n空惹意阑珊\n禄走白云间  \n幸福的事也隐藏在云中而失去，是失去倚赖吧。\n携琴走远山  \n拿着琴走往山中的样子是表示捨去人世的意思。\n不遇神仙面  \n在走往山中的途中，没有遇到仙人传授道理，心中不安吧。\n空惹意阑珊  \n心中空虚、发呆，方法用尽不知如何是好吧。更换心情，不要抱着太大的野心地在人世间过生活吧。\n愿望：难实现吧。\n疾病：危险吧。\n遗失物：难出现吧。\n盼望的人：坏吧。\n盖新居、搬家：坏吧。\n旅行：坏吧。\n结婚、交往：全部坏吧。",
        ]
